==> ejc-probid-api-3.0.0-20220714.030602-2-sources.jar: com/ejianc/business/bid/vo/PrequalificationVO.java <==
package com.ejianc.business.bid.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 资格预审
 * 
 * @author generator
 * 
 */
public class PrequalificationVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long projectId; // 招标项目Id
    private String projectName; // 招标项目名称（带入）
    private String projectCode; // 招标项目编号
    private String constructionUnit; // 建设单位
    private Date registrationDeadline; // 报名截止日期
    private Date openingDate; // 开标日期
    private Long bidUnitId; // 投标单位
    private String bidUnitName; // 投标单位 名称
    private String bidUnitCode; // 投标单位 编码
    private Integer estimatedResult; // 预审结果
    private Date theDate; // 办理日期
    private String employeeCode; // 经办人编码
    private String employeeName; // 经办人名称
    private Long employeeId; // 经办人
    private Date commitData; // 提交日期
    private Integer billState; // 单据状态 ：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private String billCode; // 编码
    private Date commitDate; // 提交日期
    private Date effectiveDate; // 生效日期
    private String commitUserCode; // 提交人账号
    private String commitUserName; // 提交人名字
    private String memo; // 备注
    

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getConstructionUnit() {
        return constructionUnit;
    }

    public void setConstructionUnit(String constructionUnit) {
        this.constructionUnit = constructionUnit;
    }
    public Date getRegistrationDeadline() {
        return registrationDeadline;
    }

    public void setRegistrationDeadline(Date registrationDeadline) {
        this.registrationDeadline = registrationDeadline;
    }
    public Date getOpeningDate() {
        return openingDate;
    }

    public void setOpeningDate(Date openingDate) {
        this.openingDate = openingDate;
    }
    public Long getBidUnitId() {
        return bidUnitId;
    }

    public void setBidUnitId(Long bidUnitId) {
        this.bidUnitId = bidUnitId;
    }
    public String getBidUnitName() {
        return bidUnitName;
    }

    public void setBidUnitName(String bidUnitName) {
        this.bidUnitName = bidUnitName;
    }
    public String getBidUnitCode() {
        return bidUnitCode;
    }

    public void setBidUnitCode(String bidUnitCode) {
        this.bidUnitCode = bidUnitCode;
    }
    public Integer getEstimatedResult() {
        return estimatedResult;
    }

    public void setEstimatedResult(Integer estimatedResult) {
        this.estimatedResult = estimatedResult;
    }
    public Date getTheDate() {
        return theDate;
    }

    public void setTheDate(Date theDate) {
        this.theDate = theDate;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public Date getCommitData() {
        return commitData;
    }

    public void setCommitData(Date commitData) {
        this.commitData = commitData;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-probid-api-3.0.0-20220715.084523-9-sources.jar: com/ejianc/business/bid/vo/PrequalificationVO.java <==
package com.ejianc.business.bid.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 资格预审
 * 
 * @author generator
 * 
 */
public class PrequalificationVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long projectId; // 招标项目Id
    private String projectName; // 招标项目名称（带入）
    private String projectCode; // 招标项目编号
    private String constructionUnit; // 建设单位
    private Date registrationDeadline; // 报名截止日期
    private Date openingDate; // 开标日期
    private Long bidUnitId; // 投标单位
    private String bidUnitName; // 投标单位 名称
    private String bidUnitCode; // 投标单位 编码
    private Integer estimatedResult; // 预审结果
    private Date theDate; // 办理日期
    private String employeeCode; // 经办人编码
    private String employeeName; // 经办人名称
    private Long employeeId; // 经办人
    private Date commitData; // 提交日期
    private Integer billState; // 单据状态 ：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private String billCode; // 编码
    private Date commitDate; // 提交日期
    private Date effectiveDate; // 生效日期
    private String commitUserCode; // 提交人账号
    private String commitUserName; // 提交人名字
    private String memo; // 备注

    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private String orgCode; // 组织编码
    private Long parentOrgId; // 项目部所属组织id
    private String parentOrgName; // 项目部所属组织名称
    private String parentOrgCode; // 项目部所属组织编码

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getConstructionUnit() {
        return constructionUnit;
    }

    public void setConstructionUnit(String constructionUnit) {
        this.constructionUnit = constructionUnit;
    }
    public Date getRegistrationDeadline() {
        return registrationDeadline;
    }

    public void setRegistrationDeadline(Date registrationDeadline) {
        this.registrationDeadline = registrationDeadline;
    }
    public Date getOpeningDate() {
        return openingDate;
    }

    public void setOpeningDate(Date openingDate) {
        this.openingDate = openingDate;
    }
    public Long getBidUnitId() {
        return bidUnitId;
    }

    public void setBidUnitId(Long bidUnitId) {
        this.bidUnitId = bidUnitId;
    }
    public String getBidUnitName() {
        return bidUnitName;
    }

    public void setBidUnitName(String bidUnitName) {
        this.bidUnitName = bidUnitName;
    }
    public String getBidUnitCode() {
        return bidUnitCode;
    }

    public void setBidUnitCode(String bidUnitCode) {
        this.bidUnitCode = bidUnitCode;
    }
    public Integer getEstimatedResult() {
        return estimatedResult;
    }

    public void setEstimatedResult(Integer estimatedResult) {
        this.estimatedResult = estimatedResult;
    }
    public Date getTheDate() {
        return theDate;
    }

    public void setTheDate(Date theDate) {
        this.theDate = theDate;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public Date getCommitData() {
        return commitData;
    }

    public void setCommitData(Date commitData) {
        this.commitData = commitData;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
